# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['LoadBalancerArgs', 'LoadBalancer']

@pulumi.input_type
class LoadBalancerArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[builtins.str],
                 vpc_id: pulumi.Input[builtins.str],
                 address_ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 delete_protection: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip_billing_config: Optional[pulumi.Input['LoadBalancerEipBillingConfigArgs']] = None,
                 global_accelerator: Optional[pulumi.Input['LoadBalancerGlobalAcceleratorArgs']] = None,
                 ipv6_eip_billing_config: Optional[pulumi.Input['LoadBalancerIpv6EipBillingConfigArgs']] = None,
                 load_balancer_billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 load_balancer_edition: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_name: Optional[pulumi.Input[builtins.str]] = None,
                 modification_protection_reason: Optional[pulumi.Input[builtins.str]] = None,
                 modification_protection_status: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTagArgs']]]] = None,
                 waf_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 waf_protected_domain: Optional[pulumi.Input[builtins.str]] = None,
                 waf_protection_enabled: Optional[pulumi.Input[builtins.str]] = None,
                 zone_mappings: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerZoneMappingArgs']]]] = None):
        """
        The set of arguments for constructing a LoadBalancer resource.
        :param pulumi.Input[builtins.str] type: ALB 实例的类型。取值是 public 或 private 。public：表示创建一个公网负载均衡实例，系统会分配一个公网IP地址和一个私网IP地址，可用于转发公网请求和私网请求。private：表示创建一个私网负载均衡实例，系统会分配一个私网IP地址，仅用于转发私网请求。
        :param pulumi.Input[builtins.str] vpc_id: 负载均衡实例所属的私有网络（VPC）的ID。
        :param pulumi.Input[builtins.str] address_ip_version: ALB 实例的 IP 类型。IPv4：IPv4 类型；DualStack：IPv4&IPv6 双栈类型。
        :param pulumi.Input[builtins.str] bandwidth_package_id: 绑定的共享带宽包ID，可实现带宽共享。
        :param pulumi.Input[builtins.str] delete_protection: 删除保护开关。on：开启；off：关闭。
        :param pulumi.Input[builtins.str] description: ALB 实例的描述。
        :param pulumi.Input['LoadBalancerEipBillingConfigArgs'] eip_billing_config: 公网IP的计费配置，仅适用于公网实例。
        :param pulumi.Input['LoadBalancerGlobalAcceleratorArgs'] global_accelerator: 全球加速器配置，用于提升跨地域访问速度。
        :param pulumi.Input['LoadBalancerIpv6EipBillingConfigArgs'] ipv6_eip_billing_config: IPv6公网IP的计費配置，仅适用于公网实例。
        :param pulumi.Input[builtins.int] load_balancer_billing_type: ALB实例计费类型，当前仅支持按量计费（取值为1）。
        :param pulumi.Input[builtins.str] load_balancer_edition: 应用型负载均衡的版本。Basic：基础版；Standard：标准版。
        :param pulumi.Input[builtins.str] load_balancer_name: ALB 实例的名称。
        :param pulumi.Input[builtins.str] modification_protection_reason: 修改保护原因。仅在 ModificationProtectionStatus 为 ConsoleProtection 时，该参数有效且合法。
        :param pulumi.Input[builtins.str] modification_protection_status: 修改保护状态。NonProtection：不保护；ConsoleProtection：控制台修改保护，通过控制台无法修改实例配置。
        :param pulumi.Input[builtins.str] project_name: 实例所属项目名称。
        :param pulumi.Input[builtins.str] waf_instance_id: ALB 实例绑定的 WAF 安全防护实例 ID。
        :param pulumi.Input[builtins.str] waf_protected_domain: WAF防护的域名，用于精确匹配防护规则。
        :param pulumi.Input[builtins.str] waf_protection_enabled: WAF 安全防护开关。on：开启；off：关闭。
        """
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "vpc_id", vpc_id)
        if address_ip_version is not None:
            pulumi.set(__self__, "address_ip_version", address_ip_version)
        if bandwidth_package_id is not None:
            pulumi.set(__self__, "bandwidth_package_id", bandwidth_package_id)
        if delete_protection is not None:
            pulumi.set(__self__, "delete_protection", delete_protection)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if eip_billing_config is not None:
            pulumi.set(__self__, "eip_billing_config", eip_billing_config)
        if global_accelerator is not None:
            pulumi.set(__self__, "global_accelerator", global_accelerator)
        if ipv6_eip_billing_config is not None:
            pulumi.set(__self__, "ipv6_eip_billing_config", ipv6_eip_billing_config)
        if load_balancer_billing_type is not None:
            pulumi.set(__self__, "load_balancer_billing_type", load_balancer_billing_type)
        if load_balancer_edition is not None:
            pulumi.set(__self__, "load_balancer_edition", load_balancer_edition)
        if load_balancer_name is not None:
            pulumi.set(__self__, "load_balancer_name", load_balancer_name)
        if modification_protection_reason is not None:
            pulumi.set(__self__, "modification_protection_reason", modification_protection_reason)
        if modification_protection_status is not None:
            pulumi.set(__self__, "modification_protection_status", modification_protection_status)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if waf_instance_id is not None:
            pulumi.set(__self__, "waf_instance_id", waf_instance_id)
        if waf_protected_domain is not None:
            pulumi.set(__self__, "waf_protected_domain", waf_protected_domain)
        if waf_protection_enabled is not None:
            pulumi.set(__self__, "waf_protection_enabled", waf_protection_enabled)
        if zone_mappings is not None:
            pulumi.set(__self__, "zone_mappings", zone_mappings)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[builtins.str]:
        """
        ALB 实例的类型。取值是 public 或 private 。public：表示创建一个公网负载均衡实例，系统会分配一个公网IP地址和一个私网IP地址，可用于转发公网请求和私网请求。private：表示创建一个私网负载均衡实例，系统会分配一个私网IP地址，仅用于转发私网请求。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        负载均衡实例所属的私有网络（VPC）的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="addressIpVersion")
    def address_ip_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ALB 实例的 IP 类型。IPv4：IPv4 类型；DualStack：IPv4&IPv6 双栈类型。
        """
        return pulumi.get(self, "address_ip_version")

    @address_ip_version.setter
    def address_ip_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "address_ip_version", value)

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        绑定的共享带宽包ID，可实现带宽共享。
        """
        return pulumi.get(self, "bandwidth_package_id")

    @bandwidth_package_id.setter
    def bandwidth_package_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "bandwidth_package_id", value)

    @property
    @pulumi.getter(name="deleteProtection")
    def delete_protection(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        删除保护开关。on：开启；off：关闭。
        """
        return pulumi.get(self, "delete_protection")

    @delete_protection.setter
    def delete_protection(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "delete_protection", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ALB 实例的描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="eipBillingConfig")
    def eip_billing_config(self) -> Optional[pulumi.Input['LoadBalancerEipBillingConfigArgs']]:
        """
        公网IP的计费配置，仅适用于公网实例。
        """
        return pulumi.get(self, "eip_billing_config")

    @eip_billing_config.setter
    def eip_billing_config(self, value: Optional[pulumi.Input['LoadBalancerEipBillingConfigArgs']]):
        pulumi.set(self, "eip_billing_config", value)

    @property
    @pulumi.getter(name="globalAccelerator")
    def global_accelerator(self) -> Optional[pulumi.Input['LoadBalancerGlobalAcceleratorArgs']]:
        """
        全球加速器配置，用于提升跨地域访问速度。
        """
        return pulumi.get(self, "global_accelerator")

    @global_accelerator.setter
    def global_accelerator(self, value: Optional[pulumi.Input['LoadBalancerGlobalAcceleratorArgs']]):
        pulumi.set(self, "global_accelerator", value)

    @property
    @pulumi.getter(name="ipv6EipBillingConfig")
    def ipv6_eip_billing_config(self) -> Optional[pulumi.Input['LoadBalancerIpv6EipBillingConfigArgs']]:
        """
        IPv6公网IP的计費配置，仅适用于公网实例。
        """
        return pulumi.get(self, "ipv6_eip_billing_config")

    @ipv6_eip_billing_config.setter
    def ipv6_eip_billing_config(self, value: Optional[pulumi.Input['LoadBalancerIpv6EipBillingConfigArgs']]):
        pulumi.set(self, "ipv6_eip_billing_config", value)

    @property
    @pulumi.getter(name="loadBalancerBillingType")
    def load_balancer_billing_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        ALB实例计费类型，当前仅支持按量计费（取值为1）。
        """
        return pulumi.get(self, "load_balancer_billing_type")

    @load_balancer_billing_type.setter
    def load_balancer_billing_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "load_balancer_billing_type", value)

    @property
    @pulumi.getter(name="loadBalancerEdition")
    def load_balancer_edition(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        应用型负载均衡的版本。Basic：基础版；Standard：标准版。
        """
        return pulumi.get(self, "load_balancer_edition")

    @load_balancer_edition.setter
    def load_balancer_edition(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "load_balancer_edition", value)

    @property
    @pulumi.getter(name="loadBalancerName")
    def load_balancer_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ALB 实例的名称。
        """
        return pulumi.get(self, "load_balancer_name")

    @load_balancer_name.setter
    def load_balancer_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "load_balancer_name", value)

    @property
    @pulumi.getter(name="modificationProtectionReason")
    def modification_protection_reason(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        修改保护原因。仅在 ModificationProtectionStatus 为 ConsoleProtection 时，该参数有效且合法。
        """
        return pulumi.get(self, "modification_protection_reason")

    @modification_protection_reason.setter
    def modification_protection_reason(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "modification_protection_reason", value)

    @property
    @pulumi.getter(name="modificationProtectionStatus")
    def modification_protection_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        修改保护状态。NonProtection：不保护；ConsoleProtection：控制台修改保护，通过控制台无法修改实例配置。
        """
        return pulumi.get(self, "modification_protection_status")

    @modification_protection_status.setter
    def modification_protection_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "modification_protection_status", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="wafInstanceId")
    def waf_instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ALB 实例绑定的 WAF 安全防护实例 ID。
        """
        return pulumi.get(self, "waf_instance_id")

    @waf_instance_id.setter
    def waf_instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "waf_instance_id", value)

    @property
    @pulumi.getter(name="wafProtectedDomain")
    def waf_protected_domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        WAF防护的域名，用于精确匹配防护规则。
        """
        return pulumi.get(self, "waf_protected_domain")

    @waf_protected_domain.setter
    def waf_protected_domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "waf_protected_domain", value)

    @property
    @pulumi.getter(name="wafProtectionEnabled")
    def waf_protection_enabled(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        WAF 安全防护开关。on：开启；off：关闭。
        """
        return pulumi.get(self, "waf_protection_enabled")

    @waf_protection_enabled.setter
    def waf_protection_enabled(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "waf_protection_enabled", value)

    @property
    @pulumi.getter(name="zoneMappings")
    def zone_mappings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerZoneMappingArgs']]]]:
        return pulumi.get(self, "zone_mappings")

    @zone_mappings.setter
    def zone_mappings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerZoneMappingArgs']]]]):
        pulumi.set(self, "zone_mappings", value)


@pulumi.input_type
class _LoadBalancerState:
    def __init__(__self__, *,
                 address_ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 business_status: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 delete_protection: Optional[pulumi.Input[builtins.str]] = None,
                 deleted_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dns_name: Optional[pulumi.Input[builtins.str]] = None,
                 eip_billing_config: Optional[pulumi.Input['LoadBalancerEipBillingConfigArgs']] = None,
                 global_accelerator: Optional[pulumi.Input['LoadBalancerGlobalAcceleratorArgs']] = None,
                 ipv6_eip_billing_config: Optional[pulumi.Input['LoadBalancerIpv6EipBillingConfigArgs']] = None,
                 load_balancer_billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 load_balancer_edition: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_id: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_name: Optional[pulumi.Input[builtins.str]] = None,
                 lock_reason: Optional[pulumi.Input[builtins.str]] = None,
                 modification_protection_reason: Optional[pulumi.Input[builtins.str]] = None,
                 modification_protection_status: Optional[pulumi.Input[builtins.str]] = None,
                 overdue_time: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTagArgs']]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 update_time: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 waf_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 waf_protected_domain: Optional[pulumi.Input[builtins.str]] = None,
                 waf_protection_enabled: Optional[pulumi.Input[builtins.str]] = None,
                 zone_mappings: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerZoneMappingArgs']]]] = None):
        """
        Input properties used for looking up and filtering LoadBalancer resources.
        :param pulumi.Input[builtins.str] address_ip_version: ALB 实例的 IP 类型。IPv4：IPv4 类型；DualStack：IPv4&IPv6 双栈类型。
        :param pulumi.Input[builtins.str] bandwidth_package_id: 绑定的共享带宽包ID，可实现带宽共享。
        :param pulumi.Input[builtins.str] business_status: ALB 实例的服务状态。Normal：正常；FinancialLocked：因欠费被锁定。
        :param pulumi.Input[builtins.str] create_time: ALB 实例的创建时间。
        :param pulumi.Input[builtins.str] delete_protection: 删除保护开关。on：开启；off：关闭。
        :param pulumi.Input[builtins.str] deleted_time: ALB 实例的预期回收时间。该参数只有实例处于 FinancialLocked 状态时有返回值。
        :param pulumi.Input[builtins.str] description: ALB 实例的描述。
        :param pulumi.Input[builtins.str] dns_name: DNS域名。
        :param pulumi.Input['LoadBalancerEipBillingConfigArgs'] eip_billing_config: 公网IP的计费配置，仅适用于公网实例。
        :param pulumi.Input['LoadBalancerGlobalAcceleratorArgs'] global_accelerator: 全球加速器配置，用于提升跨地域访问速度。
        :param pulumi.Input['LoadBalancerIpv6EipBillingConfigArgs'] ipv6_eip_billing_config: IPv6公网IP的计費配置，仅适用于公网实例。
        :param pulumi.Input[builtins.int] load_balancer_billing_type: ALB实例计费类型，当前仅支持按量计费（取值为1）。
        :param pulumi.Input[builtins.str] load_balancer_edition: 应用型负载均衡的版本。Basic：基础版；Standard：标准版。
        :param pulumi.Input[builtins.str] load_balancer_id: ALB 实例 ID。
        :param pulumi.Input[builtins.str] load_balancer_name: ALB 实例的名称。
        :param pulumi.Input[builtins.str] lock_reason: ALB 实例被冻结的原因，例如 Financial（欠费）或 Security（安全原因）。仅在实例被锁定时返回。
        :param pulumi.Input[builtins.str] modification_protection_reason: 修改保护原因。仅在 ModificationProtectionStatus 为 ConsoleProtection 时，该参数有效且合法。
        :param pulumi.Input[builtins.str] modification_protection_status: 修改保护状态。NonProtection：不保护；ConsoleProtection：控制台修改保护，通过控制台无法修改实例配置。
        :param pulumi.Input[builtins.str] overdue_time: ALB 实例的冻结时间。该参数只有实例处于 FinancialLocked 状态时有返回值。
        :param pulumi.Input[builtins.str] project_name: 实例所属项目名称。
        :param pulumi.Input[builtins.str] status: ALB 实例状态：Active（运行中）、Provisioning（创建中）、Configuring（配置中）、Deleting（删除中）、CreateFailed（创建失败）、Inactive（已停止）。
        :param pulumi.Input[builtins.str] type: ALB 实例的类型。取值是 public 或 private 。public：表示创建一个公网负载均衡实例，系统会分配一个公网IP地址和一个私网IP地址，可用于转发公网请求和私网请求。private：表示创建一个私网负载均衡实例，系统会分配一个私网IP地址，仅用于转发私网请求。
        :param pulumi.Input[builtins.str] update_time: ALB 实例的最后更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 负载均衡实例所属的私有网络（VPC）的ID。
        :param pulumi.Input[builtins.str] waf_instance_id: ALB 实例绑定的 WAF 安全防护实例 ID。
        :param pulumi.Input[builtins.str] waf_protected_domain: WAF防护的域名，用于精确匹配防护规则。
        :param pulumi.Input[builtins.str] waf_protection_enabled: WAF 安全防护开关。on：开启；off：关闭。
        """
        if address_ip_version is not None:
            pulumi.set(__self__, "address_ip_version", address_ip_version)
        if bandwidth_package_id is not None:
            pulumi.set(__self__, "bandwidth_package_id", bandwidth_package_id)
        if business_status is not None:
            pulumi.set(__self__, "business_status", business_status)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if delete_protection is not None:
            pulumi.set(__self__, "delete_protection", delete_protection)
        if deleted_time is not None:
            pulumi.set(__self__, "deleted_time", deleted_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dns_name is not None:
            pulumi.set(__self__, "dns_name", dns_name)
        if eip_billing_config is not None:
            pulumi.set(__self__, "eip_billing_config", eip_billing_config)
        if global_accelerator is not None:
            pulumi.set(__self__, "global_accelerator", global_accelerator)
        if ipv6_eip_billing_config is not None:
            pulumi.set(__self__, "ipv6_eip_billing_config", ipv6_eip_billing_config)
        if load_balancer_billing_type is not None:
            pulumi.set(__self__, "load_balancer_billing_type", load_balancer_billing_type)
        if load_balancer_edition is not None:
            pulumi.set(__self__, "load_balancer_edition", load_balancer_edition)
        if load_balancer_id is not None:
            pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        if load_balancer_name is not None:
            pulumi.set(__self__, "load_balancer_name", load_balancer_name)
        if lock_reason is not None:
            pulumi.set(__self__, "lock_reason", lock_reason)
        if modification_protection_reason is not None:
            pulumi.set(__self__, "modification_protection_reason", modification_protection_reason)
        if modification_protection_status is not None:
            pulumi.set(__self__, "modification_protection_status", modification_protection_status)
        if overdue_time is not None:
            pulumi.set(__self__, "overdue_time", overdue_time)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if waf_instance_id is not None:
            pulumi.set(__self__, "waf_instance_id", waf_instance_id)
        if waf_protected_domain is not None:
            pulumi.set(__self__, "waf_protected_domain", waf_protected_domain)
        if waf_protection_enabled is not None:
            pulumi.set(__self__, "waf_protection_enabled", waf_protection_enabled)
        if zone_mappings is not None:
            pulumi.set(__self__, "zone_mappings", zone_mappings)

    @property
    @pulumi.getter(name="addressIpVersion")
    def address_ip_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ALB 实例的 IP 类型。IPv4：IPv4 类型；DualStack：IPv4&IPv6 双栈类型。
        """
        return pulumi.get(self, "address_ip_version")

    @address_ip_version.setter
    def address_ip_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "address_ip_version", value)

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        绑定的共享带宽包ID，可实现带宽共享。
        """
        return pulumi.get(self, "bandwidth_package_id")

    @bandwidth_package_id.setter
    def bandwidth_package_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "bandwidth_package_id", value)

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ALB 实例的服务状态。Normal：正常；FinancialLocked：因欠费被锁定。
        """
        return pulumi.get(self, "business_status")

    @business_status.setter
    def business_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "business_status", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ALB 实例的创建时间。
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="deleteProtection")
    def delete_protection(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        删除保护开关。on：开启；off：关闭。
        """
        return pulumi.get(self, "delete_protection")

    @delete_protection.setter
    def delete_protection(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "delete_protection", value)

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ALB 实例的预期回收时间。该参数只有实例处于 FinancialLocked 状态时有返回值。
        """
        return pulumi.get(self, "deleted_time")

    @deleted_time.setter
    def deleted_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deleted_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ALB 实例的描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dnsName")
    def dns_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNS域名。
        """
        return pulumi.get(self, "dns_name")

    @dns_name.setter
    def dns_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dns_name", value)

    @property
    @pulumi.getter(name="eipBillingConfig")
    def eip_billing_config(self) -> Optional[pulumi.Input['LoadBalancerEipBillingConfigArgs']]:
        """
        公网IP的计费配置，仅适用于公网实例。
        """
        return pulumi.get(self, "eip_billing_config")

    @eip_billing_config.setter
    def eip_billing_config(self, value: Optional[pulumi.Input['LoadBalancerEipBillingConfigArgs']]):
        pulumi.set(self, "eip_billing_config", value)

    @property
    @pulumi.getter(name="globalAccelerator")
    def global_accelerator(self) -> Optional[pulumi.Input['LoadBalancerGlobalAcceleratorArgs']]:
        """
        全球加速器配置，用于提升跨地域访问速度。
        """
        return pulumi.get(self, "global_accelerator")

    @global_accelerator.setter
    def global_accelerator(self, value: Optional[pulumi.Input['LoadBalancerGlobalAcceleratorArgs']]):
        pulumi.set(self, "global_accelerator", value)

    @property
    @pulumi.getter(name="ipv6EipBillingConfig")
    def ipv6_eip_billing_config(self) -> Optional[pulumi.Input['LoadBalancerIpv6EipBillingConfigArgs']]:
        """
        IPv6公网IP的计費配置，仅适用于公网实例。
        """
        return pulumi.get(self, "ipv6_eip_billing_config")

    @ipv6_eip_billing_config.setter
    def ipv6_eip_billing_config(self, value: Optional[pulumi.Input['LoadBalancerIpv6EipBillingConfigArgs']]):
        pulumi.set(self, "ipv6_eip_billing_config", value)

    @property
    @pulumi.getter(name="loadBalancerBillingType")
    def load_balancer_billing_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        ALB实例计费类型，当前仅支持按量计费（取值为1）。
        """
        return pulumi.get(self, "load_balancer_billing_type")

    @load_balancer_billing_type.setter
    def load_balancer_billing_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "load_balancer_billing_type", value)

    @property
    @pulumi.getter(name="loadBalancerEdition")
    def load_balancer_edition(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        应用型负载均衡的版本。Basic：基础版；Standard：标准版。
        """
        return pulumi.get(self, "load_balancer_edition")

    @load_balancer_edition.setter
    def load_balancer_edition(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "load_balancer_edition", value)

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ALB 实例 ID。
        """
        return pulumi.get(self, "load_balancer_id")

    @load_balancer_id.setter
    def load_balancer_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "load_balancer_id", value)

    @property
    @pulumi.getter(name="loadBalancerName")
    def load_balancer_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ALB 实例的名称。
        """
        return pulumi.get(self, "load_balancer_name")

    @load_balancer_name.setter
    def load_balancer_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "load_balancer_name", value)

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ALB 实例被冻结的原因，例如 Financial（欠费）或 Security（安全原因）。仅在实例被锁定时返回。
        """
        return pulumi.get(self, "lock_reason")

    @lock_reason.setter
    def lock_reason(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "lock_reason", value)

    @property
    @pulumi.getter(name="modificationProtectionReason")
    def modification_protection_reason(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        修改保护原因。仅在 ModificationProtectionStatus 为 ConsoleProtection 时，该参数有效且合法。
        """
        return pulumi.get(self, "modification_protection_reason")

    @modification_protection_reason.setter
    def modification_protection_reason(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "modification_protection_reason", value)

    @property
    @pulumi.getter(name="modificationProtectionStatus")
    def modification_protection_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        修改保护状态。NonProtection：不保护；ConsoleProtection：控制台修改保护，通过控制台无法修改实例配置。
        """
        return pulumi.get(self, "modification_protection_status")

    @modification_protection_status.setter
    def modification_protection_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "modification_protection_status", value)

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ALB 实例的冻结时间。该参数只有实例处于 FinancialLocked 状态时有返回值。
        """
        return pulumi.get(self, "overdue_time")

    @overdue_time.setter
    def overdue_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "overdue_time", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ALB 实例状态：Active（运行中）、Provisioning（创建中）、Configuring（配置中）、Deleting（删除中）、CreateFailed（创建失败）、Inactive（已停止）。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ALB 实例的类型。取值是 public 或 private 。public：表示创建一个公网负载均衡实例，系统会分配一个公网IP地址和一个私网IP地址，可用于转发公网请求和私网请求。private：表示创建一个私网负载均衡实例，系统会分配一个私网IP地址，仅用于转发私网请求。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ALB 实例的最后更新时间。
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_time", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        负载均衡实例所属的私有网络（VPC）的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="wafInstanceId")
    def waf_instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ALB 实例绑定的 WAF 安全防护实例 ID。
        """
        return pulumi.get(self, "waf_instance_id")

    @waf_instance_id.setter
    def waf_instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "waf_instance_id", value)

    @property
    @pulumi.getter(name="wafProtectedDomain")
    def waf_protected_domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        WAF防护的域名，用于精确匹配防护规则。
        """
        return pulumi.get(self, "waf_protected_domain")

    @waf_protected_domain.setter
    def waf_protected_domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "waf_protected_domain", value)

    @property
    @pulumi.getter(name="wafProtectionEnabled")
    def waf_protection_enabled(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        WAF 安全防护开关。on：开启；off：关闭。
        """
        return pulumi.get(self, "waf_protection_enabled")

    @waf_protection_enabled.setter
    def waf_protection_enabled(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "waf_protection_enabled", value)

    @property
    @pulumi.getter(name="zoneMappings")
    def zone_mappings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerZoneMappingArgs']]]]:
        return pulumi.get(self, "zone_mappings")

    @zone_mappings.setter
    def zone_mappings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerZoneMappingArgs']]]]):
        pulumi.set(self, "zone_mappings", value)


@pulumi.type_token("bytepluscc:alb/loadBalancer:LoadBalancer")
class LoadBalancer(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address_ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 delete_protection: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip_billing_config: Optional[pulumi.Input[Union['LoadBalancerEipBillingConfigArgs', 'LoadBalancerEipBillingConfigArgsDict']]] = None,
                 global_accelerator: Optional[pulumi.Input[Union['LoadBalancerGlobalAcceleratorArgs', 'LoadBalancerGlobalAcceleratorArgsDict']]] = None,
                 ipv6_eip_billing_config: Optional[pulumi.Input[Union['LoadBalancerIpv6EipBillingConfigArgs', 'LoadBalancerIpv6EipBillingConfigArgsDict']]] = None,
                 load_balancer_billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 load_balancer_edition: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_name: Optional[pulumi.Input[builtins.str]] = None,
                 modification_protection_reason: Optional[pulumi.Input[builtins.str]] = None,
                 modification_protection_status: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerTagArgs', 'LoadBalancerTagArgsDict']]]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 waf_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 waf_protected_domain: Optional[pulumi.Input[builtins.str]] = None,
                 waf_protection_enabled: Optional[pulumi.Input[builtins.str]] = None,
                 zone_mappings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerZoneMappingArgs', 'LoadBalancerZoneMappingArgsDict']]]]] = None,
                 __props__=None):
        """
        应用型负载均衡（ALB）是对“七层”网络协议的流量进行分发的服务。

        ## Import

        ```sh
        $ pulumi import bytepluscc:alb/loadBalancer:LoadBalancer example "load_balancer_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] address_ip_version: ALB 实例的 IP 类型。IPv4：IPv4 类型；DualStack：IPv4&IPv6 双栈类型。
        :param pulumi.Input[builtins.str] bandwidth_package_id: 绑定的共享带宽包ID，可实现带宽共享。
        :param pulumi.Input[builtins.str] delete_protection: 删除保护开关。on：开启；off：关闭。
        :param pulumi.Input[builtins.str] description: ALB 实例的描述。
        :param pulumi.Input[Union['LoadBalancerEipBillingConfigArgs', 'LoadBalancerEipBillingConfigArgsDict']] eip_billing_config: 公网IP的计费配置，仅适用于公网实例。
        :param pulumi.Input[Union['LoadBalancerGlobalAcceleratorArgs', 'LoadBalancerGlobalAcceleratorArgsDict']] global_accelerator: 全球加速器配置，用于提升跨地域访问速度。
        :param pulumi.Input[Union['LoadBalancerIpv6EipBillingConfigArgs', 'LoadBalancerIpv6EipBillingConfigArgsDict']] ipv6_eip_billing_config: IPv6公网IP的计費配置，仅适用于公网实例。
        :param pulumi.Input[builtins.int] load_balancer_billing_type: ALB实例计费类型，当前仅支持按量计费（取值为1）。
        :param pulumi.Input[builtins.str] load_balancer_edition: 应用型负载均衡的版本。Basic：基础版；Standard：标准版。
        :param pulumi.Input[builtins.str] load_balancer_name: ALB 实例的名称。
        :param pulumi.Input[builtins.str] modification_protection_reason: 修改保护原因。仅在 ModificationProtectionStatus 为 ConsoleProtection 时，该参数有效且合法。
        :param pulumi.Input[builtins.str] modification_protection_status: 修改保护状态。NonProtection：不保护；ConsoleProtection：控制台修改保护，通过控制台无法修改实例配置。
        :param pulumi.Input[builtins.str] project_name: 实例所属项目名称。
        :param pulumi.Input[builtins.str] type: ALB 实例的类型。取值是 public 或 private 。public：表示创建一个公网负载均衡实例，系统会分配一个公网IP地址和一个私网IP地址，可用于转发公网请求和私网请求。private：表示创建一个私网负载均衡实例，系统会分配一个私网IP地址，仅用于转发私网请求。
        :param pulumi.Input[builtins.str] vpc_id: 负载均衡实例所属的私有网络（VPC）的ID。
        :param pulumi.Input[builtins.str] waf_instance_id: ALB 实例绑定的 WAF 安全防护实例 ID。
        :param pulumi.Input[builtins.str] waf_protected_domain: WAF防护的域名，用于精确匹配防护规则。
        :param pulumi.Input[builtins.str] waf_protection_enabled: WAF 安全防护开关。on：开启；off：关闭。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LoadBalancerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        应用型负载均衡（ALB）是对“七层”网络协议的流量进行分发的服务。

        ## Import

        ```sh
        $ pulumi import bytepluscc:alb/loadBalancer:LoadBalancer example "load_balancer_id"
        ```

        :param str resource_name: The name of the resource.
        :param LoadBalancerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LoadBalancerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address_ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 delete_protection: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip_billing_config: Optional[pulumi.Input[Union['LoadBalancerEipBillingConfigArgs', 'LoadBalancerEipBillingConfigArgsDict']]] = None,
                 global_accelerator: Optional[pulumi.Input[Union['LoadBalancerGlobalAcceleratorArgs', 'LoadBalancerGlobalAcceleratorArgsDict']]] = None,
                 ipv6_eip_billing_config: Optional[pulumi.Input[Union['LoadBalancerIpv6EipBillingConfigArgs', 'LoadBalancerIpv6EipBillingConfigArgsDict']]] = None,
                 load_balancer_billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 load_balancer_edition: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_name: Optional[pulumi.Input[builtins.str]] = None,
                 modification_protection_reason: Optional[pulumi.Input[builtins.str]] = None,
                 modification_protection_status: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerTagArgs', 'LoadBalancerTagArgsDict']]]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 waf_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 waf_protected_domain: Optional[pulumi.Input[builtins.str]] = None,
                 waf_protection_enabled: Optional[pulumi.Input[builtins.str]] = None,
                 zone_mappings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerZoneMappingArgs', 'LoadBalancerZoneMappingArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LoadBalancerArgs.__new__(LoadBalancerArgs)

            __props__.__dict__["address_ip_version"] = address_ip_version
            __props__.__dict__["bandwidth_package_id"] = bandwidth_package_id
            __props__.__dict__["delete_protection"] = delete_protection
            __props__.__dict__["description"] = description
            __props__.__dict__["eip_billing_config"] = eip_billing_config
            __props__.__dict__["global_accelerator"] = global_accelerator
            __props__.__dict__["ipv6_eip_billing_config"] = ipv6_eip_billing_config
            __props__.__dict__["load_balancer_billing_type"] = load_balancer_billing_type
            __props__.__dict__["load_balancer_edition"] = load_balancer_edition
            __props__.__dict__["load_balancer_name"] = load_balancer_name
            __props__.__dict__["modification_protection_reason"] = modification_protection_reason
            __props__.__dict__["modification_protection_status"] = modification_protection_status
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["tags"] = tags
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["waf_instance_id"] = waf_instance_id
            __props__.__dict__["waf_protected_domain"] = waf_protected_domain
            __props__.__dict__["waf_protection_enabled"] = waf_protection_enabled
            __props__.__dict__["zone_mappings"] = zone_mappings
            __props__.__dict__["business_status"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["deleted_time"] = None
            __props__.__dict__["dns_name"] = None
            __props__.__dict__["load_balancer_id"] = None
            __props__.__dict__["lock_reason"] = None
            __props__.__dict__["overdue_time"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["update_time"] = None
        super(LoadBalancer, __self__).__init__(
            'bytepluscc:alb/loadBalancer:LoadBalancer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            address_ip_version: Optional[pulumi.Input[builtins.str]] = None,
            bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
            business_status: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            delete_protection: Optional[pulumi.Input[builtins.str]] = None,
            deleted_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            dns_name: Optional[pulumi.Input[builtins.str]] = None,
            eip_billing_config: Optional[pulumi.Input[Union['LoadBalancerEipBillingConfigArgs', 'LoadBalancerEipBillingConfigArgsDict']]] = None,
            global_accelerator: Optional[pulumi.Input[Union['LoadBalancerGlobalAcceleratorArgs', 'LoadBalancerGlobalAcceleratorArgsDict']]] = None,
            ipv6_eip_billing_config: Optional[pulumi.Input[Union['LoadBalancerIpv6EipBillingConfigArgs', 'LoadBalancerIpv6EipBillingConfigArgsDict']]] = None,
            load_balancer_billing_type: Optional[pulumi.Input[builtins.int]] = None,
            load_balancer_edition: Optional[pulumi.Input[builtins.str]] = None,
            load_balancer_id: Optional[pulumi.Input[builtins.str]] = None,
            load_balancer_name: Optional[pulumi.Input[builtins.str]] = None,
            lock_reason: Optional[pulumi.Input[builtins.str]] = None,
            modification_protection_reason: Optional[pulumi.Input[builtins.str]] = None,
            modification_protection_status: Optional[pulumi.Input[builtins.str]] = None,
            overdue_time: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerTagArgs', 'LoadBalancerTagArgsDict']]]]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None,
            update_time: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            waf_instance_id: Optional[pulumi.Input[builtins.str]] = None,
            waf_protected_domain: Optional[pulumi.Input[builtins.str]] = None,
            waf_protection_enabled: Optional[pulumi.Input[builtins.str]] = None,
            zone_mappings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LoadBalancerZoneMappingArgs', 'LoadBalancerZoneMappingArgsDict']]]]] = None) -> 'LoadBalancer':
        """
        Get an existing LoadBalancer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] address_ip_version: ALB 实例的 IP 类型。IPv4：IPv4 类型；DualStack：IPv4&IPv6 双栈类型。
        :param pulumi.Input[builtins.str] bandwidth_package_id: 绑定的共享带宽包ID，可实现带宽共享。
        :param pulumi.Input[builtins.str] business_status: ALB 实例的服务状态。Normal：正常；FinancialLocked：因欠费被锁定。
        :param pulumi.Input[builtins.str] create_time: ALB 实例的创建时间。
        :param pulumi.Input[builtins.str] delete_protection: 删除保护开关。on：开启；off：关闭。
        :param pulumi.Input[builtins.str] deleted_time: ALB 实例的预期回收时间。该参数只有实例处于 FinancialLocked 状态时有返回值。
        :param pulumi.Input[builtins.str] description: ALB 实例的描述。
        :param pulumi.Input[builtins.str] dns_name: DNS域名。
        :param pulumi.Input[Union['LoadBalancerEipBillingConfigArgs', 'LoadBalancerEipBillingConfigArgsDict']] eip_billing_config: 公网IP的计费配置，仅适用于公网实例。
        :param pulumi.Input[Union['LoadBalancerGlobalAcceleratorArgs', 'LoadBalancerGlobalAcceleratorArgsDict']] global_accelerator: 全球加速器配置，用于提升跨地域访问速度。
        :param pulumi.Input[Union['LoadBalancerIpv6EipBillingConfigArgs', 'LoadBalancerIpv6EipBillingConfigArgsDict']] ipv6_eip_billing_config: IPv6公网IP的计費配置，仅适用于公网实例。
        :param pulumi.Input[builtins.int] load_balancer_billing_type: ALB实例计费类型，当前仅支持按量计费（取值为1）。
        :param pulumi.Input[builtins.str] load_balancer_edition: 应用型负载均衡的版本。Basic：基础版；Standard：标准版。
        :param pulumi.Input[builtins.str] load_balancer_id: ALB 实例 ID。
        :param pulumi.Input[builtins.str] load_balancer_name: ALB 实例的名称。
        :param pulumi.Input[builtins.str] lock_reason: ALB 实例被冻结的原因，例如 Financial（欠费）或 Security（安全原因）。仅在实例被锁定时返回。
        :param pulumi.Input[builtins.str] modification_protection_reason: 修改保护原因。仅在 ModificationProtectionStatus 为 ConsoleProtection 时，该参数有效且合法。
        :param pulumi.Input[builtins.str] modification_protection_status: 修改保护状态。NonProtection：不保护；ConsoleProtection：控制台修改保护，通过控制台无法修改实例配置。
        :param pulumi.Input[builtins.str] overdue_time: ALB 实例的冻结时间。该参数只有实例处于 FinancialLocked 状态时有返回值。
        :param pulumi.Input[builtins.str] project_name: 实例所属项目名称。
        :param pulumi.Input[builtins.str] status: ALB 实例状态：Active（运行中）、Provisioning（创建中）、Configuring（配置中）、Deleting（删除中）、CreateFailed（创建失败）、Inactive（已停止）。
        :param pulumi.Input[builtins.str] type: ALB 实例的类型。取值是 public 或 private 。public：表示创建一个公网负载均衡实例，系统会分配一个公网IP地址和一个私网IP地址，可用于转发公网请求和私网请求。private：表示创建一个私网负载均衡实例，系统会分配一个私网IP地址，仅用于转发私网请求。
        :param pulumi.Input[builtins.str] update_time: ALB 实例的最后更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 负载均衡实例所属的私有网络（VPC）的ID。
        :param pulumi.Input[builtins.str] waf_instance_id: ALB 实例绑定的 WAF 安全防护实例 ID。
        :param pulumi.Input[builtins.str] waf_protected_domain: WAF防护的域名，用于精确匹配防护规则。
        :param pulumi.Input[builtins.str] waf_protection_enabled: WAF 安全防护开关。on：开启；off：关闭。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LoadBalancerState.__new__(_LoadBalancerState)

        __props__.__dict__["address_ip_version"] = address_ip_version
        __props__.__dict__["bandwidth_package_id"] = bandwidth_package_id
        __props__.__dict__["business_status"] = business_status
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["delete_protection"] = delete_protection
        __props__.__dict__["deleted_time"] = deleted_time
        __props__.__dict__["description"] = description
        __props__.__dict__["dns_name"] = dns_name
        __props__.__dict__["eip_billing_config"] = eip_billing_config
        __props__.__dict__["global_accelerator"] = global_accelerator
        __props__.__dict__["ipv6_eip_billing_config"] = ipv6_eip_billing_config
        __props__.__dict__["load_balancer_billing_type"] = load_balancer_billing_type
        __props__.__dict__["load_balancer_edition"] = load_balancer_edition
        __props__.__dict__["load_balancer_id"] = load_balancer_id
        __props__.__dict__["load_balancer_name"] = load_balancer_name
        __props__.__dict__["lock_reason"] = lock_reason
        __props__.__dict__["modification_protection_reason"] = modification_protection_reason
        __props__.__dict__["modification_protection_status"] = modification_protection_status
        __props__.__dict__["overdue_time"] = overdue_time
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["type"] = type
        __props__.__dict__["update_time"] = update_time
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["waf_instance_id"] = waf_instance_id
        __props__.__dict__["waf_protected_domain"] = waf_protected_domain
        __props__.__dict__["waf_protection_enabled"] = waf_protection_enabled
        __props__.__dict__["zone_mappings"] = zone_mappings
        return LoadBalancer(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="addressIpVersion")
    def address_ip_version(self) -> pulumi.Output[builtins.str]:
        """
        ALB 实例的 IP 类型。IPv4：IPv4 类型；DualStack：IPv4&IPv6 双栈类型。
        """
        return pulumi.get(self, "address_ip_version")

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> pulumi.Output[builtins.str]:
        """
        绑定的共享带宽包ID，可实现带宽共享。
        """
        return pulumi.get(self, "bandwidth_package_id")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> pulumi.Output[builtins.str]:
        """
        ALB 实例的服务状态。Normal：正常；FinancialLocked：因欠费被锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        ALB 实例的创建时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="deleteProtection")
    def delete_protection(self) -> pulumi.Output[builtins.str]:
        """
        删除保护开关。on：开启；off：关闭。
        """
        return pulumi.get(self, "delete_protection")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> pulumi.Output[builtins.str]:
        """
        ALB 实例的预期回收时间。该参数只有实例处于 FinancialLocked 状态时有返回值。
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        ALB 实例的描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dnsName")
    def dns_name(self) -> pulumi.Output[builtins.str]:
        """
        DNS域名。
        """
        return pulumi.get(self, "dns_name")

    @property
    @pulumi.getter(name="eipBillingConfig")
    def eip_billing_config(self) -> pulumi.Output['outputs.LoadBalancerEipBillingConfig']:
        """
        公网IP的计费配置，仅适用于公网实例。
        """
        return pulumi.get(self, "eip_billing_config")

    @property
    @pulumi.getter(name="globalAccelerator")
    def global_accelerator(self) -> pulumi.Output['outputs.LoadBalancerGlobalAccelerator']:
        """
        全球加速器配置，用于提升跨地域访问速度。
        """
        return pulumi.get(self, "global_accelerator")

    @property
    @pulumi.getter(name="ipv6EipBillingConfig")
    def ipv6_eip_billing_config(self) -> pulumi.Output['outputs.LoadBalancerIpv6EipBillingConfig']:
        """
        IPv6公网IP的计費配置，仅适用于公网实例。
        """
        return pulumi.get(self, "ipv6_eip_billing_config")

    @property
    @pulumi.getter(name="loadBalancerBillingType")
    def load_balancer_billing_type(self) -> pulumi.Output[builtins.int]:
        """
        ALB实例计费类型，当前仅支持按量计费（取值为1）。
        """
        return pulumi.get(self, "load_balancer_billing_type")

    @property
    @pulumi.getter(name="loadBalancerEdition")
    def load_balancer_edition(self) -> pulumi.Output[builtins.str]:
        """
        应用型负载均衡的版本。Basic：基础版；Standard：标准版。
        """
        return pulumi.get(self, "load_balancer_edition")

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> pulumi.Output[builtins.str]:
        """
        ALB 实例 ID。
        """
        return pulumi.get(self, "load_balancer_id")

    @property
    @pulumi.getter(name="loadBalancerName")
    def load_balancer_name(self) -> pulumi.Output[builtins.str]:
        """
        ALB 实例的名称。
        """
        return pulumi.get(self, "load_balancer_name")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> pulumi.Output[builtins.str]:
        """
        ALB 实例被冻结的原因，例如 Financial（欠费）或 Security（安全原因）。仅在实例被锁定时返回。
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="modificationProtectionReason")
    def modification_protection_reason(self) -> pulumi.Output[builtins.str]:
        """
        修改保护原因。仅在 ModificationProtectionStatus 为 ConsoleProtection 时，该参数有效且合法。
        """
        return pulumi.get(self, "modification_protection_reason")

    @property
    @pulumi.getter(name="modificationProtectionStatus")
    def modification_protection_status(self) -> pulumi.Output[builtins.str]:
        """
        修改保护状态。NonProtection：不保护；ConsoleProtection：控制台修改保护，通过控制台无法修改实例配置。
        """
        return pulumi.get(self, "modification_protection_status")

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> pulumi.Output[builtins.str]:
        """
        ALB 实例的冻结时间。该参数只有实例处于 FinancialLocked 状态时有返回值。
        """
        return pulumi.get(self, "overdue_time")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        实例所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        ALB 实例状态：Active（运行中）、Provisioning（创建中）、Configuring（配置中）、Deleting（删除中）、CreateFailed（创建失败）、Inactive（已停止）。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.LoadBalancerTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        ALB 实例的类型。取值是 public 或 private 。public：表示创建一个公网负载均衡实例，系统会分配一个公网IP地址和一个私网IP地址，可用于转发公网请求和私网请求。private：表示创建一个私网负载均衡实例，系统会分配一个私网IP地址，仅用于转发私网请求。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[builtins.str]:
        """
        ALB 实例的最后更新时间。
        """
        return pulumi.get(self, "update_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        负载均衡实例所属的私有网络（VPC）的ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="wafInstanceId")
    def waf_instance_id(self) -> pulumi.Output[builtins.str]:
        """
        ALB 实例绑定的 WAF 安全防护实例 ID。
        """
        return pulumi.get(self, "waf_instance_id")

    @property
    @pulumi.getter(name="wafProtectedDomain")
    def waf_protected_domain(self) -> pulumi.Output[builtins.str]:
        """
        WAF防护的域名，用于精确匹配防护规则。
        """
        return pulumi.get(self, "waf_protected_domain")

    @property
    @pulumi.getter(name="wafProtectionEnabled")
    def waf_protection_enabled(self) -> pulumi.Output[builtins.str]:
        """
        WAF 安全防护开关。on：开启；off：关闭。
        """
        return pulumi.get(self, "waf_protection_enabled")

    @property
    @pulumi.getter(name="zoneMappings")
    def zone_mappings(self) -> pulumi.Output[Sequence['outputs.LoadBalancerZoneMapping']]:
        return pulumi.get(self, "zone_mappings")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GroupArgs', 'Group']

@pulumi.input_type
class GroupArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 group_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 reset_info: Optional[pulumi.Input['GroupResetInfoArgs']] = None):
        """
        The set of arguments for constructing a Group resource.
        :param pulumi.Input[builtins.str] description: Consumer Group 描述。
        :param pulumi.Input[builtins.str] group_name: 自定义设置Consumer Group 的名称，约束限制如下：只能由小写英文字符、数字、下划线和中划线（-）组成。长度为 3~64 字符。
        :param pulumi.Input[builtins.str] instance_id: 所属 BMQ 实例 ID。
        :param pulumi.Input['GroupResetInfoArgs'] reset_info: 重置消费位点信息。
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if group_name is not None:
            pulumi.set(__self__, "group_name", group_name)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if reset_info is not None:
            pulumi.set(__self__, "reset_info", reset_info)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Consumer Group 描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        自定义设置Consumer Group 的名称，约束限制如下：只能由小写英文字符、数字、下划线和中划线（-）组成。长度为 3~64 字符。
        """
        return pulumi.get(self, "group_name")

    @group_name.setter
    def group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group_name", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        所属 BMQ 实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="resetInfo")
    def reset_info(self) -> Optional[pulumi.Input['GroupResetInfoArgs']]:
        """
        重置消费位点信息。
        """
        return pulumi.get(self, "reset_info")

    @reset_info.setter
    def reset_info(self, value: Optional[pulumi.Input['GroupResetInfoArgs']]):
        pulumi.set(self, "reset_info", value)


@pulumi.input_type
class _GroupState:
    def __init__(__self__, *,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 group_id: Optional[pulumi.Input[builtins.str]] = None,
                 group_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 owner_id: Optional[pulumi.Input[builtins.str]] = None,
                 owner_name: Optional[pulumi.Input[builtins.str]] = None,
                 reset_info: Optional[pulumi.Input['GroupResetInfoArgs']] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 topic_infos: Optional[pulumi.Input[Sequence[pulumi.Input['GroupTopicInfoArgs']]]] = None):
        """
        Input properties used for looking up and filtering Group resources.
        :param pulumi.Input[builtins.str] created_time: Consumer Group 创建时间。
        :param pulumi.Input[builtins.str] description: Consumer Group 描述。
        :param pulumi.Input[builtins.str] group_id: Consumer Group 的 ID。
        :param pulumi.Input[builtins.str] group_name: 自定义设置Consumer Group 的名称，约束限制如下：只能由小写英文字符、数字、下划线和中划线（-）组成。长度为 3~64 字符。
        :param pulumi.Input[builtins.str] instance_id: 所属 BMQ 实例 ID。
        :param pulumi.Input[builtins.str] owner_id: Consumer Group 所属用户的 ID。
        :param pulumi.Input[builtins.str] owner_name: Consumer Group 所属用户的名称。
        :param pulumi.Input['GroupResetInfoArgs'] reset_info: 重置消费位点信息。
        :param pulumi.Input[builtins.str] status: Consumer Group 的状态。
        """
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if group_name is not None:
            pulumi.set(__self__, "group_name", group_name)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if owner_id is not None:
            pulumi.set(__self__, "owner_id", owner_id)
        if owner_name is not None:
            pulumi.set(__self__, "owner_name", owner_name)
        if reset_info is not None:
            pulumi.set(__self__, "reset_info", reset_info)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if topic_infos is not None:
            pulumi.set(__self__, "topic_infos", topic_infos)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Consumer Group 创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Consumer Group 描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Consumer Group 的 ID。
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        自定义设置Consumer Group 的名称，约束限制如下：只能由小写英文字符、数字、下划线和中划线（-）组成。长度为 3~64 字符。
        """
        return pulumi.get(self, "group_name")

    @group_name.setter
    def group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group_name", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        所属 BMQ 实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="ownerId")
    def owner_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Consumer Group 所属用户的 ID。
        """
        return pulumi.get(self, "owner_id")

    @owner_id.setter
    def owner_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "owner_id", value)

    @property
    @pulumi.getter(name="ownerName")
    def owner_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Consumer Group 所属用户的名称。
        """
        return pulumi.get(self, "owner_name")

    @owner_name.setter
    def owner_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "owner_name", value)

    @property
    @pulumi.getter(name="resetInfo")
    def reset_info(self) -> Optional[pulumi.Input['GroupResetInfoArgs']]:
        """
        重置消费位点信息。
        """
        return pulumi.get(self, "reset_info")

    @reset_info.setter
    def reset_info(self, value: Optional[pulumi.Input['GroupResetInfoArgs']]):
        pulumi.set(self, "reset_info", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Consumer Group 的状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="topicInfos")
    def topic_infos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupTopicInfoArgs']]]]:
        return pulumi.get(self, "topic_infos")

    @topic_infos.setter
    def topic_infos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupTopicInfoArgs']]]]):
        pulumi.set(self, "topic_infos", value)


@pulumi.type_token("bytepluscc:bmq/group:Group")
class Group(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 group_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 reset_info: Optional[pulumi.Input[Union['GroupResetInfoArgs', 'GroupResetInfoArgsDict']]] = None,
                 __props__=None):
        """
        一组具有相同 Group ID 的消费端。当一个 Topic 被同一个 Group 的多个 Consumer 消费时，每一条消息都只会被投递到一个 Consumer，实现消费的负载均衡。通过 Group，您可以确保一个 Topic 的消息被并行消费。

        ## Import

        ```sh
        $ pulumi import bytepluscc:bmq/group:Group example "group_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Consumer Group 描述。
        :param pulumi.Input[builtins.str] group_name: 自定义设置Consumer Group 的名称，约束限制如下：只能由小写英文字符、数字、下划线和中划线（-）组成。长度为 3~64 字符。
        :param pulumi.Input[builtins.str] instance_id: 所属 BMQ 实例 ID。
        :param pulumi.Input[Union['GroupResetInfoArgs', 'GroupResetInfoArgsDict']] reset_info: 重置消费位点信息。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[GroupArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        一组具有相同 Group ID 的消费端。当一个 Topic 被同一个 Group 的多个 Consumer 消费时，每一条消息都只会被投递到一个 Consumer，实现消费的负载均衡。通过 Group，您可以确保一个 Topic 的消息被并行消费。

        ## Import

        ```sh
        $ pulumi import bytepluscc:bmq/group:Group example "group_id"
        ```

        :param str resource_name: The name of the resource.
        :param GroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 group_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 reset_info: Optional[pulumi.Input[Union['GroupResetInfoArgs', 'GroupResetInfoArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupArgs.__new__(GroupArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["group_name"] = group_name
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["reset_info"] = reset_info
            __props__.__dict__["created_time"] = None
            __props__.__dict__["group_id"] = None
            __props__.__dict__["owner_id"] = None
            __props__.__dict__["owner_name"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["topic_infos"] = None
        super(Group, __self__).__init__(
            'bytepluscc:bmq/group:Group',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            group_id: Optional[pulumi.Input[builtins.str]] = None,
            group_name: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            owner_id: Optional[pulumi.Input[builtins.str]] = None,
            owner_name: Optional[pulumi.Input[builtins.str]] = None,
            reset_info: Optional[pulumi.Input[Union['GroupResetInfoArgs', 'GroupResetInfoArgsDict']]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            topic_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupTopicInfoArgs', 'GroupTopicInfoArgsDict']]]]] = None) -> 'Group':
        """
        Get an existing Group resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_time: Consumer Group 创建时间。
        :param pulumi.Input[builtins.str] description: Consumer Group 描述。
        :param pulumi.Input[builtins.str] group_id: Consumer Group 的 ID。
        :param pulumi.Input[builtins.str] group_name: 自定义设置Consumer Group 的名称，约束限制如下：只能由小写英文字符、数字、下划线和中划线（-）组成。长度为 3~64 字符。
        :param pulumi.Input[builtins.str] instance_id: 所属 BMQ 实例 ID。
        :param pulumi.Input[builtins.str] owner_id: Consumer Group 所属用户的 ID。
        :param pulumi.Input[builtins.str] owner_name: Consumer Group 所属用户的名称。
        :param pulumi.Input[Union['GroupResetInfoArgs', 'GroupResetInfoArgsDict']] reset_info: 重置消费位点信息。
        :param pulumi.Input[builtins.str] status: Consumer Group 的状态。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupState.__new__(_GroupState)

        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["group_name"] = group_name
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["owner_id"] = owner_id
        __props__.__dict__["owner_name"] = owner_name
        __props__.__dict__["reset_info"] = reset_info
        __props__.__dict__["status"] = status
        __props__.__dict__["topic_infos"] = topic_infos
        return Group(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        Consumer Group 创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        Consumer Group 描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[builtins.str]:
        """
        Consumer Group 的 ID。
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> pulumi.Output[builtins.str]:
        """
        自定义设置Consumer Group 的名称，约束限制如下：只能由小写英文字符、数字、下划线和中划线（-）组成。长度为 3~64 字符。
        """
        return pulumi.get(self, "group_name")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        所属 BMQ 实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="ownerId")
    def owner_id(self) -> pulumi.Output[builtins.str]:
        """
        Consumer Group 所属用户的 ID。
        """
        return pulumi.get(self, "owner_id")

    @property
    @pulumi.getter(name="ownerName")
    def owner_name(self) -> pulumi.Output[builtins.str]:
        """
        Consumer Group 所属用户的名称。
        """
        return pulumi.get(self, "owner_name")

    @property
    @pulumi.getter(name="resetInfo")
    def reset_info(self) -> pulumi.Output['outputs.GroupResetInfo']:
        """
        重置消费位点信息。
        """
        return pulumi.get(self, "reset_info")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Consumer Group 的状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="topicInfos")
    def topic_infos(self) -> pulumi.Output[Sequence['outputs.GroupTopicInfo']]:
        return pulumi.get(self, "topic_infos")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetSnapshotResult',
    'AwaitableGetSnapshotResult',
    'get_snapshot',
    'get_snapshot_output',
]

@pulumi.output_type
class GetSnapshotResult:
    """
    A collection of values returned by getSnapshot.
    """
    def __init__(__self__, created_time=None, description=None, file_system_id=None, file_system_name=None, id=None, is_encrypt=None, progress=None, retention_days=None, snapshot_id=None, snapshot_name=None, snapshot_type=None, source_size=None, source_version=None, status=None, zone_id=None):
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if file_system_id and not isinstance(file_system_id, str):
            raise TypeError("Expected argument 'file_system_id' to be a str")
        pulumi.set(__self__, "file_system_id", file_system_id)
        if file_system_name and not isinstance(file_system_name, str):
            raise TypeError("Expected argument 'file_system_name' to be a str")
        pulumi.set(__self__, "file_system_name", file_system_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_encrypt and not isinstance(is_encrypt, bool):
            raise TypeError("Expected argument 'is_encrypt' to be a bool")
        pulumi.set(__self__, "is_encrypt", is_encrypt)
        if progress and not isinstance(progress, str):
            raise TypeError("Expected argument 'progress' to be a str")
        pulumi.set(__self__, "progress", progress)
        if retention_days and not isinstance(retention_days, int):
            raise TypeError("Expected argument 'retention_days' to be a int")
        pulumi.set(__self__, "retention_days", retention_days)
        if snapshot_id and not isinstance(snapshot_id, str):
            raise TypeError("Expected argument 'snapshot_id' to be a str")
        pulumi.set(__self__, "snapshot_id", snapshot_id)
        if snapshot_name and not isinstance(snapshot_name, str):
            raise TypeError("Expected argument 'snapshot_name' to be a str")
        pulumi.set(__self__, "snapshot_name", snapshot_name)
        if snapshot_type and not isinstance(snapshot_type, str):
            raise TypeError("Expected argument 'snapshot_type' to be a str")
        pulumi.set(__self__, "snapshot_type", snapshot_type)
        if source_size and not isinstance(source_size, int):
            raise TypeError("Expected argument 'source_size' to be a int")
        pulumi.set(__self__, "source_size", source_size)
        if source_version and not isinstance(source_version, str):
            raise TypeError("Expected argument 'source_version' to be a str")
        pulumi.set(__self__, "source_version", source_version)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        快照创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        快照描述信息。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> builtins.str:
        """
        文件系统 ID。
        """
        return pulumi.get(self, "file_system_id")

    @property
    @pulumi.getter(name="fileSystemName")
    def file_system_name(self) -> builtins.str:
        """
        文件系统名称。
        """
        return pulumi.get(self, "file_system_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isEncrypt")
    def is_encrypt(self) -> builtins.bool:
        """
        是否加密，当前仅支持false，即不加密。
        """
        return pulumi.get(self, "is_encrypt")

    @property
    @pulumi.getter
    def progress(self) -> builtins.str:
        """
        快照创建进度。
        """
        return pulumi.get(self, "progress")

    @property
    @pulumi.getter(name="retentionDays")
    def retention_days(self) -> builtins.int:
        """
        快照保留时间，默认为2147483647，即永久保留。
        """
        return pulumi.get(self, "retention_days")

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> builtins.str:
        """
        快照 ID。
        """
        return pulumi.get(self, "snapshot_id")

    @property
    @pulumi.getter(name="snapshotName")
    def snapshot_name(self) -> builtins.str:
        """
        快照名称。
        """
        return pulumi.get(self, "snapshot_name")

    @property
    @pulumi.getter(name="snapshotType")
    def snapshot_type(self) -> builtins.str:
        """
        快照类型，默认为Manual，即手动快照。
        """
        return pulumi.get(self, "snapshot_type")

    @property
    @pulumi.getter(name="sourceSize")
    def source_size(self) -> builtins.int:
        """
        文件系统容量，单位为 GiB。
        """
        return pulumi.get(self, "source_size")

    @property
    @pulumi.getter(name="sourceVersion")
    def source_version(self) -> builtins.str:
        """
        文件系统版本。
        """
        return pulumi.get(self, "source_version")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        快照状态。说明如下：Progressing：正在创建。Accomplished：创建成功。Failed：创建失败。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> builtins.str:
        """
        可用区 ID。
        """
        return pulumi.get(self, "zone_id")


class AwaitableGetSnapshotResult(GetSnapshotResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSnapshotResult(
            created_time=self.created_time,
            description=self.description,
            file_system_id=self.file_system_id,
            file_system_name=self.file_system_name,
            id=self.id,
            is_encrypt=self.is_encrypt,
            progress=self.progress,
            retention_days=self.retention_days,
            snapshot_id=self.snapshot_id,
            snapshot_name=self.snapshot_name,
            snapshot_type=self.snapshot_type,
            source_size=self.source_size,
            source_version=self.source_version,
            status=self.status,
            zone_id=self.zone_id)


def get_snapshot(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSnapshotResult:
    """
    Data Source schema for Byteplus::FileNAS::Snapshot


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:filenas/getSnapshot:getSnapshot', __args__, opts=opts, typ=GetSnapshotResult).value

    return AwaitableGetSnapshotResult(
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        file_system_id=pulumi.get(__ret__, 'file_system_id'),
        file_system_name=pulumi.get(__ret__, 'file_system_name'),
        id=pulumi.get(__ret__, 'id'),
        is_encrypt=pulumi.get(__ret__, 'is_encrypt'),
        progress=pulumi.get(__ret__, 'progress'),
        retention_days=pulumi.get(__ret__, 'retention_days'),
        snapshot_id=pulumi.get(__ret__, 'snapshot_id'),
        snapshot_name=pulumi.get(__ret__, 'snapshot_name'),
        snapshot_type=pulumi.get(__ret__, 'snapshot_type'),
        source_size=pulumi.get(__ret__, 'source_size'),
        source_version=pulumi.get(__ret__, 'source_version'),
        status=pulumi.get(__ret__, 'status'),
        zone_id=pulumi.get(__ret__, 'zone_id'))
def get_snapshot_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSnapshotResult]:
    """
    Data Source schema for Byteplus::FileNAS::Snapshot


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:filenas/getSnapshot:getSnapshot', __args__, opts=opts, typ=GetSnapshotResult)
    return __ret__.apply(lambda __response__: GetSnapshotResult(
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        file_system_id=pulumi.get(__response__, 'file_system_id'),
        file_system_name=pulumi.get(__response__, 'file_system_name'),
        id=pulumi.get(__response__, 'id'),
        is_encrypt=pulumi.get(__response__, 'is_encrypt'),
        progress=pulumi.get(__response__, 'progress'),
        retention_days=pulumi.get(__response__, 'retention_days'),
        snapshot_id=pulumi.get(__response__, 'snapshot_id'),
        snapshot_name=pulumi.get(__response__, 'snapshot_name'),
        snapshot_type=pulumi.get(__response__, 'snapshot_type'),
        source_size=pulumi.get(__response__, 'source_size'),
        source_version=pulumi.get(__response__, 'source_version'),
        status=pulumi.get(__response__, 'status'),
        zone_id=pulumi.get(__response__, 'zone_id')))
